@@ -8,17 +8,20 @@ __author__ = 'stanislav bashkirtsev'
 
 
 class EnvironmentConfigGrabber:
-  CLONE_REPO_TO = '/tmp/jtalks-cicd/environments'
-  GRABBED_CONFIGS_LOCATION = CLONE_REPO_TO + "/configs"
   logger = Logger("EnvironmentConfigGrabber")
 
-  def __init__(self, env_configs_root):
+  def __init__(self, env_configs_root, temp_dir):
     self.env_configs_root = env_configs_root
+    self.temp_dir = temp_dir
+    self.clone_repo_to = temp_dir + 'environments'
+    self.grabbed_configs_location = self.clone_repo_to + "/configs"
+
 
   def grab_jtalks_configs(self):
     try:
       self.__remove_previous_git_folder__()
-      repo.Repo.clone_from('git@jtalks.org:environments', self.CLONE_REPO_TO)
+      self.__create_jtalks_temp_dir__()
+      repo.Repo.clone_from('git@jtalks.org:environments', self.clone_repo_to)
       self.__copy_grabbed_configs_into_work_dir__()
     except GitCommandError:
       self.logger.warn("You don't have access to JTalks repo with environment configs. You may want to use your own "
@@ -28,24 +31,28 @@ class EnvironmentConfigGrabber:
 
   def __remove_previous_git_folder__(self):
     try:
-      if os.path.exists(self.CLONE_REPO_TO):
-        self.logger.info("Removing {0} directory if it was there", self.CLONE_REPO_TO)
-        shutil.rmtree(self.CLONE_REPO_TO)
+      if os.path.exists(self.clone_repo_to):
+        self.logger.info("Removing {0} directory if it was there", self.clone_repo_to)
+        shutil.rmtree(self.clone_repo_to)
     except OSError as e:
       if e.errno is not 2:#No such file or directory
         self.logger.warn(e.message)
 
   def __copy_grabbed_configs_into_work_dir__(self):
-    grabbed_dirs_and_files = os.listdir(self.GRABBED_CONFIGS_LOCATION)
+    grabbed_dirs_and_files = os.listdir(self.grabbed_configs_location)
     for next_grabbed_file_or_dir in grabbed_dirs_and_files:
       destination_file = self.env_configs_root + next_grabbed_file_or_dir
       if os.path.exists(destination_file):
         self.logger.info("{0} will be overwritten by newer version from git repo", destination_file)
         self.__delete_file_or_dir__(destination_file)
-      shutil.move(self.GRABBED_CONFIGS_LOCATION + "/" + next_grabbed_file_or_dir, destination_file)
+      shutil.move(self.grabbed_configs_location + "/" + next_grabbed_file_or_dir, destination_file)
 
   def __delete_file_or_dir__(self, destination_file):
     if os.path.isfile(destination_file):
       os.remove(destination_file)
     else:
       shutil.rmtree(destination_file)
+
+  def __create_jtalks_temp_dir__(self):
+    if not os.path.exists(self.temp_dir):
+      os.mkdir(self.temp_dir)
